@@ -66,8 +66,11 @@ impl_parse! {
         "skip_deserializing" => out.0.skip = true,
         "skip_serializing_if" => out.0.optional = parse_assign_str(input)? == *"Option::is_none",
         "flatten" => out.0.flatten = true,
+        // parse #[serde(default)] to not emit a warning
         "default" => {
-            if !input.is_empty() {
+            use syn::Token;
+            if input.peek(Token![=]) {
+                input.parse::<Token![=]>()?;
                 parse_assign_str(input)?;
             }
         },
