@@ -8,6 +8,10 @@ pub(crate) fn unit(attr: &StructAttr, name: &str) -> Result<DerivedTS> {
         syn_err!("`rename_all` is not applicable to unit structs");
     }
 
+    if attr.tag.is_some() {
+        syn_err!("`tag` is not applicable to unit structs");
+    }
+
     Ok(DerivedTS {
         inline: quote!("null".to_owned()),
         decl: quote!(format!("type {} = null;", #name)),
